@@ -53,6 +53,7 @@ class Simulation(ABC):
         self.image_quality = 2000
         self.video_quality = 1000
         self.fps = 10
+        self.tpb = 96    # blocks per grid for CUDA neighbor search
 
     @abstractmethod
     def setup(self):
@@ -194,7 +195,7 @@ class Simulation(ABC):
                 edge_count = cuda.to_device(edge_count)
 
                 # specify threads-per-block and blocks-per-grid values
-                tpb = 72
+                tpb = self.tpb
                 bpg = math.ceil(self.number_agents / tpb)
 
                 # call the CUDA kernel, sending arrays to GPU
@@ -344,7 +345,7 @@ class Simulation(ABC):
                 # get xy coordinates, the axis lengths, and color of agent
                 x, y = int(scale * self.locations[index][0]), int(scale * self.locations[index][1])
                 major, minor = int(scale * self.radii[index]), int(scale * self.radii[index])
-                color = (int(self.colors[index][2]), int(self.colors[index][1]), int(self.colors[index][1]))
+                color = (int(self.colors[index][2]), int(self.colors[index][1]), int(self.colors[index][0]))
 
                 # draw the agent and a black outline to distinguish overlapping agents
                 image = cv2.ellipse(image, (x, y), (major, minor), 0, 0, 360, color, -1)
@@ -532,7 +533,7 @@ class Simulation(ABC):
             elif array_name == "radii":
                 array = 5 * np.ones(number)
             elif array_name == "colors":
-                array = np.full(shape, np.array([50, 50, 255]), dtype=int)
+                array = np.full(shape, np.array([0, 0, 255]), dtype=int)
             else:
                 # get data type and create array
                 dtype = self.__dict__[array_name].dtype
@@ -572,11 +573,17 @@ class Simulation(ABC):
                     # get the bounds and apply the function
                     bounds = self.agent_types[key]
                     for i in range(bounds[0], bounds[1] + 1):
-                        array[i] = initial[key]()
+                        if callable(initial[key]):
+                            array[i] = initial[key]()
+                        else:
+                            array[i] = initial[key]
             else:
                 # if no dict provided, apply function for initial condition to entire array
                 for i in range(0, self.number_agents):
-                    array[i] = initial()
+                    if callable(initial):
+                        array[i] = initial()
+                    else:
+                        array[i] = initial
 
         return array
 
@@ -700,8 +707,7 @@ class Simulation(ABC):
             simulation mode.
         """
         # get absolute path
-        output_dir = os.path.expanduser(output_dir)
-        output_dir = os.path.abspath(output_dir)
+        output_dir = os.path.abspath(os.path.expanduser(output_dir))
 
         # check that the output directory exists and get the name/mode for the simulation
         output_dir = check_output_dir(output_dir)
